Skip to main content

🕳️CygnusX1

Code by Trong-Dat Ngo.

Overviews

🕳️CygnusX1 is a multithreaded tool 🛠️, used to search and download images from popular search engines 🔎. It is straightforward to set up and run!

Key features

  • 🥰 No knowledge is required to get up and to run.
  • 🚀 Download image using customizable number of threads.
  • ⛏️Crawl all possible images (search results and recommendations).

Demo

Installation

This repository is tested on Python 3.6+ and PyTorch selenium 3.141.0+, as well as it works fine on macOS, Windows, Linux.

You should setup and run 🕳️CygnusX1 in a virtual environment. If you're unfamiliar with Python virtual environments, check out the user guide here.

First, create a virtual environment with the version of Python you're going to use and activate it. (Can be omitted if you want to set up directly on the OS environment)

source venv/bin/activate

Pip Insstallation

Install 🕳️CygnusX1 by pip:

pip install CygnusX1

Manual Installation

Download 🕳️CygnusX1 from Github:

git clone https://github.com/dat821168/CygnusX1.git

Finally install dependencies in requirements.txt:

pip install -r requirements.txt

Run

Use cygnusx1 command line:

cygnusx1  --keywords "keyword 1, keyword 2" --workers 8 --use_suggestions --headless

Use run.py to start the script:

python run.py  --keywords "keyword 1, keyword 2" --workers 8 --use_suggestions --headless

Argument details:

  • --keywords: Indicate the keywords/keyphrases you want to search. For multiple keywords, separate them with commas.
  • --out_dir: Path where to save results. Default = './IMAGES'.
  • --workers: The maximum number of workers used to crawl image. Default = 2.
  • --use_suggestions: Crawl search engine suggestions/recommendations. Default = False.
  • --headless: Hide browser during scraping. Default = False.

Future Releases

References

Release files for CygnusX1 1.0.4

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for CygnusX1 1.0.4
File Size Uploaded
CygnusX1-1.0.4.tar.gz 6.6 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for CygnusX1 1.0.4
File Interpreter ABI Platform
CygnusX1-1.0.4-py3-none-any.whl Python 3 none any Details

Total release size: 14.8 kB

Release files / CygnusX1-1.0.4.tar.gz

Download URL CygnusX1-1.0.4.tar.gz
Size 6.6 kB
Tags Source
SHA-256 checksum
How to use checksums
04790757662b206cfa2b7349b99981160d4adc1fe22e7a1b3679af5068719960
BLAKE2b-256 checksum
How to use checksums
8be8ab28eb016f39d494a06bc7d0056852cc74030cb903a6e3d30ab9f8959175
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.1.1 pkginfo/1.4.2 requests/2.26.0 setuptools/45.2.0 requests-toolbelt/0.8.0 tqdm/4.62.3 CPython/3.8.10

Release files / CygnusX1-1.0.4-py3-none-any.whl

Download URL CygnusX1-1.0.4-py3-none-any.whl
Size 8.2 kB
Tags Python 3
SHA-256 checksum
How to use checksums
c4fe3b7598fa528f998a276ac7ab9f1aaec5ba3bcbd4eb2ab81d60b43c9e36a5
BLAKE2b-256 checksum
How to use checksums
df9a516eb2e06305d235832a22acb70a182ef901cbe07f952ef29b3a741e670d
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.1.1 pkginfo/1.4.2 requests/2.26.0 setuptools/45.2.0 requests-toolbelt/0.8.0 tqdm/4.62.3 CPython/3.8.10

Release history Release notifications | RSS feed

This release

1.0.4 This release

2 release files

1.0.3

2 release files

1.0.2

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page